"use strict";
/******************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
var response = require("response-templating");
;
/******************************************************************************/
var Library = /** @class */ (function () {
    /*****************************************/
    function Library(signedIn, getCleanedUser, appNames) {
        var _this = this;
        this.signedIn = signedIn;
        this.getCleanedUser = getCleanedUser;
        this.apps = [];
        if (appNames && appNames.length)
            appNames.forEach(function (appName) { return _this.apps.push(appName); });
    }
    /*****************************************/
    Library.prototype.validateAppContext = function (app) {
        return this.apps.some(function (subject) { return subject == app; });
    };
    /*****************************************************************/
    Library.prototype.makeActiveAppCheck = function (app, view, live) {
        var _this = this;
        return function (req, res, next) {
            if (!res.locals.currentUser)
                return _this.passpointRedirect(res, app, live, null);
            var currentUser = res.locals.currentUser;
            if (currentUser.activeApps.some(function (subject) { return subject == app; }))
                return next();
            return response.send(res, view, false, "You haven't joined " + app + " yet", {
                currentUser: currentUser,
                innerContext: "get-started"
            }, live);
        };
    };
    /*****************************************************************/
    Library.prototype.makeLevelCheck = function (accessLevel, live, app, innerContext) {
        var _this = this;
        return function (req, res, next) {
            if (!_this.signedIn(req, live))
                return _this.passpointRedirect(res, app, live, innerContext);
            return _this.getCleanedUser(req, live)
                .then(function (currentUser) {
                if (currentUser.accessLevel == accessLevel) {
                    res.locals.currentUser = currentUser;
                    return next();
                }
                return _this.passpointRedirect(res, app, live, innerContext);
            });
        };
    };
    /******************************************************************************/
    Library.prototype.passpointRedirect = function (res, app, live, innerContext) {
        var queryString = (live ? "" : "/sandbox") + "/passpoint";
        if (app) {
            queryString += "?nextApp=" + app;
            if (innerContext)
                queryString += "&nextInnerContext=" + innerContext;
        }
        return res.redirect(queryString);
    };
    return Library;
}());
exports.Library = Library;
/******************************************************************************/ 
